# dear-inventory-ruby

DearInventoryRuby - the Ruby gem for the DEAR Inventory API

This specifing endpoints for DEAR Inventory API

This SDK is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 2.0.0
- Package version: 0.1.19.1
- Build package: org.openapitools.codegen.languages.RubyClientCodegen
For more information, please visit [https://www.nnhan.me](https://www.nnhan.me)

## Installation

### Build a gem

To build the Ruby code into a gem:

```shell
gem build dear-inventory-ruby.gemspec
```

Then either install the gem locally:

```shell
gem install ./dear-inventory-ruby-0.1.19.1.gem
```

(for development, run `gem install --dev ./dear-inventory-ruby-0.1.19.1.gem` to install the development dependencies)

or publish the gem to a gem hosting service, e.g. [RubyGems](https://rubygems.org/).

Finally add this to the Gemfile:

    gem 'dear-inventory-ruby', '~> 0.1.19.1'

### Install from Git

If the Ruby gem is hosted at a git repository: https://github.com/GIT_USER_ID/GIT_REPO_ID, then add the following in the Gemfile:

    gem 'dear-inventory-ruby', :git => 'https://github.com/GIT_USER_ID/GIT_REPO_ID.git'

### Include the Ruby code directly

Include the Ruby code directly using `-I` as follows:

```shell
ruby -Ilib script.rb
```

## Getting Started

Please follow the [installation](#installation) procedure and then run the following code:

```ruby
# Load the gem
require 'dear-inventory-ruby'

# Setup authorization
DearInventoryRuby.configure do |config|
  # Configure API key authorization: accountID
  config.api_key['api-auth-accountid'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api-auth-accountid'] = 'Bearer'

  # Configure API key authorization: appKey
  config.api_key['api-auth-applicationkey'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['api-auth-applicationkey'] = 'Bearer'
end

api_instance = DearInventoryRuby::InventoryApi.new
account = { "Code": "001", "Status": "ACTIVE", "Name": "Accounts Payable test", "Type": "CURRLIAB", "Description": "Outstanding invoices the company has received from suppliers but has not yet paid at balance date", "Class": "LIABILITY", "SystemAccount": "CREDITORS", } # Account | an Account object with properties to create
opts = {
  summarize_errors: false # Boolean | If false return 200 OK and mix of successfully created objects and any with validation errors
}

begin
  #Allows you to create an Account
  result = api_instance.create_account(account, opts)
  p result
rescue DearInventoryRuby::ApiError => e
  puts "Exception when calling InventoryApi->create_account: #{e}"
end

```

## Documentation for API Endpoints

All URIs are relative to *https://inventory.dearsystems.com/ExternalApi/v2*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*DearInventoryRuby::InventoryApi* | [**create_account**](docs/InventoryApi.md#create_account) | **POST** /ref/account | Allows you to create an Account
*DearInventoryRuby::InventoryApi* | [**create_customer**](docs/InventoryApi.md#create_customer) | **POST** /customer | Allows you to create a customer
*DearInventoryRuby::InventoryApi* | [**create_payment_term**](docs/InventoryApi.md#create_payment_term) | **POST** /ref/paymentterm | Allows you to create a payment term
*DearInventoryRuby::InventoryApi* | [**create_tax**](docs/InventoryApi.md#create_tax) | **POST** /ref/tax | Allows you to create a tax
*DearInventoryRuby::InventoryApi* | [**delete_account**](docs/InventoryApi.md#delete_account) | **DELETE** /ref/account | Allows you to delete an Account
*DearInventoryRuby::InventoryApi* | [**delete_payment_term**](docs/InventoryApi.md#delete_payment_term) | **DELETE** /ref/paymentterm | Allows you to delete a payment term
*DearInventoryRuby::InventoryApi* | [**get_accounts**](docs/InventoryApi.md#get_accounts) | **GET** /ref/account | Allows you to retrieve the Chart of Accounts
*DearInventoryRuby::InventoryApi* | [**get_customers**](docs/InventoryApi.md#get_customers) | **GET** /customer | Allows you to retrieve the customers
*DearInventoryRuby::InventoryApi* | [**get_me**](docs/InventoryApi.md#get_me) | **GET** /me | Allows you to retrieve your information
*DearInventoryRuby::InventoryApi* | [**get_payment_terms**](docs/InventoryApi.md#get_payment_terms) | **GET** /ref/paymentterm | Allows you to retrieve the payment terms
*DearInventoryRuby::InventoryApi* | [**get_price_tiers**](docs/InventoryApi.md#get_price_tiers) | **GET** /ref/priceTier | Allows you to retrieve the Price Tiers
*DearInventoryRuby::InventoryApi* | [**get_sale_invoices**](docs/InventoryApi.md#get_sale_invoices) | **GET** /sale/invoice | Allows you to retrieve the sale invoices
*DearInventoryRuby::InventoryApi* | [**get_taxes**](docs/InventoryApi.md#get_taxes) | **GET** /ref/tax | Allows you to retrieve the taxes
*DearInventoryRuby::InventoryApi* | [**update_account**](docs/InventoryApi.md#update_account) | **PUT** /ref/account | Allows you to update an Account
*DearInventoryRuby::InventoryApi* | [**update_customer**](docs/InventoryApi.md#update_customer) | **PUT** /customer | Allows you to update a customer
*DearInventoryRuby::InventoryApi* | [**update_payment_term**](docs/InventoryApi.md#update_payment_term) | **PUT** /ref/paymentterm | Allows you to update a payment term
*DearInventoryRuby::InventoryApi* | [**update_tax**](docs/InventoryApi.md#update_tax) | **PUT** /ref/tax | Allows you to update a tax


## Documentation for Models

 - [DearInventoryRuby::Account](docs/Account.md)
 - [DearInventoryRuby::Accounts](docs/Accounts.md)
 - [DearInventoryRuby::Address](docs/Address.md)
 - [DearInventoryRuby::Contact](docs/Contact.md)
 - [DearInventoryRuby::Customer](docs/Customer.md)
 - [DearInventoryRuby::Customers](docs/Customers.md)
 - [DearInventoryRuby::Error](docs/Error.md)
 - [DearInventoryRuby::Me](docs/Me.md)
 - [DearInventoryRuby::PaymentTerm](docs/PaymentTerm.md)
 - [DearInventoryRuby::PaymentTerms](docs/PaymentTerms.md)
 - [DearInventoryRuby::PriceTier](docs/PriceTier.md)
 - [DearInventoryRuby::PriceTiers](docs/PriceTiers.md)
 - [DearInventoryRuby::SaleInvoice](docs/SaleInvoice.md)
 - [DearInventoryRuby::SaleInvoiceAdditionalCharge](docs/SaleInvoiceAdditionalCharge.md)
 - [DearInventoryRuby::SaleInvoiceLine](docs/SaleInvoiceLine.md)
 - [DearInventoryRuby::SaleInvoices](docs/SaleInvoices.md)
 - [DearInventoryRuby::Success](docs/Success.md)
 - [DearInventoryRuby::Tax](docs/Tax.md)
 - [DearInventoryRuby::TaxComponent](docs/TaxComponent.md)
 - [DearInventoryRuby::Taxes](docs/Taxes.md)


## Documentation for Authorization


### accountID


- **Type**: API key
- **API key parameter name**: api-auth-accountid
- **Location**: HTTP header

### appKey


- **Type**: API key
- **API key parameter name**: api-auth-applicationkey
- **Location**: HTTP header

